#[non_exhaustive]pub struct UpdateAvailabilityOptionsInput {
pub domain_name: Option<String>,
pub multi_az: Option<bool>,
}Expand description
Container for the parameters to the operation. Specifies the name of the domain you want to update and the Multi-AZ availability option.UpdateAvailabilityOptions
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain_name: Option<String>A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
multi_az: Option<bool>You expand an existing search domain to a second Availability Zone by setting the Multi-AZ option to true. Similarly, you can turn off the Multi-AZ option to downgrade the domain to a single Availability Zone by setting the Multi-AZ option to false.
Implementations
Sourceimpl UpdateAvailabilityOptionsInput
impl UpdateAvailabilityOptionsInput
Sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
Sourceimpl UpdateAvailabilityOptionsInput
impl UpdateAvailabilityOptionsInput
Sourcepub fn builder() -> UpdateAvailabilityOptionsInputBuilder
pub fn builder() -> UpdateAvailabilityOptionsInputBuilder
Creates a new builder-style object to manufacture UpdateAvailabilityOptionsInput.