#[non_exhaustive]pub struct DocumentSuggesterOptions {
pub source_field: String,
pub fuzzy_matching: Option<SuggesterFuzzyMatching>,
pub sort_expression: Option<String>,
}Expand description
Options for a search suggester.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_field: StringThe name of the index field you want to use for suggestions.
fuzzy_matching: Option<SuggesterFuzzyMatching>The level of fuzziness allowed when suggesting matches for a string: none, low, or high. With none, the specified string is treated as an exact prefix. With low, suggestions must differ from the specified string by no more than one character. With high, suggestions can differ by up to two characters. The default is none.
sort_expression: Option<String>An expression that computes a score for each suggestion to control how they are sorted. The scores are rounded to the nearest integer, with a floor of 0 and a ceiling of 2^31-1. A document's relevance score is not computed for suggestions, so sort expressions cannot reference the _score value. To sort suggestions using a numeric field or existing expression, simply specify the name of the field or expression. If no expression is configured for the suggester, the suggestions are sorted with the closest matches listed first.
Implementations
Sourceimpl DocumentSuggesterOptions
impl DocumentSuggesterOptions
Sourcepub fn source_field(&self) -> &str
pub fn source_field(&self) -> &str
The name of the index field you want to use for suggestions.
Sourcepub fn fuzzy_matching(&self) -> Option<&SuggesterFuzzyMatching>
pub fn fuzzy_matching(&self) -> Option<&SuggesterFuzzyMatching>
The level of fuzziness allowed when suggesting matches for a string: none, low, or high. With none, the specified string is treated as an exact prefix. With low, suggestions must differ from the specified string by no more than one character. With high, suggestions can differ by up to two characters. The default is none.
Sourcepub fn sort_expression(&self) -> Option<&str>
pub fn sort_expression(&self) -> Option<&str>
An expression that computes a score for each suggestion to control how they are sorted. The scores are rounded to the nearest integer, with a floor of 0 and a ceiling of 2^31-1. A document's relevance score is not computed for suggestions, so sort expressions cannot reference the _score value. To sort suggestions using a numeric field or existing expression, simply specify the name of the field or expression. If no expression is configured for the suggester, the suggestions are sorted with the closest matches listed first.
Sourceimpl DocumentSuggesterOptions
impl DocumentSuggesterOptions
Sourcepub fn builder() -> DocumentSuggesterOptionsBuilder
pub fn builder() -> DocumentSuggesterOptionsBuilder
Creates a new builder-style object to manufacture DocumentSuggesterOptions.